from setuptools import find_packages,setup
setup(name='DEMO5578',#模块名
      version='1.0',#版本
      packages= find_packages(),#当前目录所有文件
      url='https://xxx.com',#说明文档下载地址
      author='wzp',#作者名
      author_email='zipangw@gmail.com',#邮箱
      )